Kungfuig.Validator behaviour (Kungfuig v0.4.0) View Source
Generic validator encapsulation.
Default implementation is
NimbleOptions.
Link to this section Summary
Callbacks
Generates a documentation for expected options
Validates given options with the schema, provided by the implementation of this behaviour
Link to this section Callbacks
Specs
Generates a documentation for expected options
Specs
Validates given options with the schema, provided by the implementation of this behaviour